package de.hawhamburg.reachability.util;

/**
 * Utility functions related to enumerations.<br><br>
 * 
 * This utility class provides some fancy utility methods related to enumeration handling.
 * 
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR} 
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public final class EnumerationUtil {
    
    /**
     * Prevent creation of instances of this utility class.
     */
    private EnumerationUtil() { }

    /**
     * Checks whether a an enumeration contains a certain value or not.
     * 
     * @param <E>           The enumeration class type. 
     * @param enumeration   The certain enumeration class which could be viewed as <i>haystack</i>.
     * @param test          The value which shall be checked as {@link String} and could be viewed as <i>needle</i>.
     * @return              <code>true</code> if the needle is part of the haystack, otherwise <code>false</code>
     */
    public static <E extends Enum<E>> boolean contains(final Class<E> enumeration,
                                                       final String test) {
        for (E x : enumeration.getEnumConstants()) {
            if (x.name().equals(test)) {
                return true;
            }
        }
        return false;
    }
}
